.. _dataformats_events:

Event lists
===========


``EVENTS`` extension
--------------------

TODO: describe 

``GTI`` extension
-----------------

`GTI description in OGIP standard <https://heasarc.gsfc.nasa.gov/docs/heasarc/ofwg/docs/rates/ogip_93_003/ogip_93_003.html#tth_sEc6.3>`__.

TODO: describe where GTIs are used.
